docs.rs failed to build tauri-plugin-audio-0.1.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
tauri-plugin-audio
Desktop-only Tauri plugin for listing audio capture devices and controlling one active CPAL/PipeWire capture stream.
The command interface is exposed through plugin:audio|get_devices, plugin:audio|create_stream, and plugin:audio|stop_stream.
Install
Register the Rust plugin in your Tauri builder:
default
.plugin
.run?;
TypeScript Bindings
Generate app-local TypeScript bindings from the crate in the consuming Tauri app:
use Typescript;
let builder = ;
builder
.export
.expect;
Use the generated bindings from your frontend:
import { commands, type StreamEvent } from "./bindings";
const devices = await commands.getDevices();